// SoftAuthClear.c
//---------------------------------------------------------------------------
// Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// Except as contained in this notice, the name of Dallas Semiconductor
// shall not be used except as stated in the Dallas Semiconductor
// Branding Policy.
//---------------------------------------------------------------------------
//
// SoftAuthClear.c - Sample device clearing app for Software Authorization.
//
// Version: 2.00

#include <stdio.h>
#include "SoftAuth.h"

void printHex(uchar bytes[], unsigned int len)
{
   unsigned int i;
   for(i=0; i<len; i++)
      printf(" %02X", (unsigned int)bytes[i]);
}

void printHexLabeled(char* szLabel, uchar bytes[], unsigned int len)
{
   printf("%s: \n   ", szLabel);
   printHex(bytes, len);
   printf("\n");
}

int main(int argc, char** argv)
{
   int rslt;
   unsigned int dataLen = 0;
   DeviceStruct device;

   if(argc<3)
   {
      (void)puts(" SoftAuthClear \"{x,y}\" \"key phrase\" z");
      (void)puts(" ");
      (void)puts("    \"{x,y}\" - port number (x) and port type (y)");
      (void)puts("            {1,6} = USB1, {1,5} = COM1, {1,2} = LPT1");
      (void)puts(" ");
      (void)puts("    \"key phrase\" - phrase used in generating key for encryption, ");
      (void)puts("                     decryption, and authentication.");
      (void)puts(" ");
      (void)puts("    z - (optional) length of data to erase from device");
      (void)puts(" ");
      return 0;
   }

   if(argc>3 && sscanf(argv[3], "%d", &dataLen)<1)
   {
      printf("dataLen must be numeral, not (%s)\n\n", argv[3]);
      return 0;
   }

   printf(" SoftAuth Clear routine\n");
   printf("    Port: %s\n", argv[1]);
   printf("    key phrase: \"%s\"\n", argv[2]);
   if(dataLen!=0)
      printf("    length of data to erase: %u\n\n", dataLen);
   else
      printf("    Erasing all available memory\n\n");

   memset(&device, 0, sizeof(device));

   if((rslt = saBeginSession(argv[1], &device))<0)
   {
      printf("Error with 1-Wire port: %d (%d)\n", device.hnd, rslt);
      OWERROR_DUMP(stdout);
      return rslt;
   }

   printf(" Successfully acquired port\n\n");

   if(rslt>0)
   {
      printf("Found Device:\n");
      printHexLabeled("romID", device.romID, 8);
      printf("\n");

      if(!saClearDevice(&device, argv[2], dataLen))
      {
         printf("Clear failed\n\n");
         OWERROR_DUMP(stdout);
      }
      else
      {
         printf("Clear Complete\n\n");
      }
   }
   else
   {
      printf("No 1-Wire devices found\n");
   }

   saEndSession(&device);
	return 0;
}